import junit.framework.*;

/**
 * Test the animation of bouncing shapes.
 * 
 * @author rick mugridge july 2004
 */
public class TestAnimator extends TestCase {
	private MockPainter painter;

	private Animator animator;

	public void setUp() {
		painter = new MockPainter();
		animator = new Animator();
	}

	public void testAnimatorClock() {
		animator.add(new MockSprite());
		animator.clock(painter);
		animator.clock(painter);
		assertEquals("(paint-1)(paint-2)", painter.toString());
	}

	public void testTwoSprites() {
		animator.add(new MockSprite());
		animator.add(new MockSprite());
		animator.clock(painter);
		assertEquals("(paint-1)(paint-1)", painter.toString());
	}

	public void testMovingShape() {
		animator.add(new RectangleShape(0, 0, 25, 35, new BouncingMotion(+12, +15))); // added 25, 35, for task 2
		animator.clock(painter);
		assertEquals("(rectangle 0,0,25,35)", painter.toString());
	}

	public void testMovingShapeTwo() {
		animator.add(new RectangleShape(1, -5, 25, 35, new BouncingMotion(112, -15))); // added 25, 35, for task 2
		animator.clock(painter);
		assertEquals("(rectangle 1,-5,25,35)", painter.toString());
	}

	public void testShapeMoveWithoutLimit() {
		animator.add(new RectangleShape(0, 0, 25, 35, new BouncingMotion(+12, +15))); // added 25, 35, for task 2
		animator.clock(painter);
		animator.clock(painter);
		animator.clock(painter);
		assertEquals("(rectangle 0,0,25,35)(rectangle 12,15,25,35)"
				+ "(rectangle 24,30,25,35)", painter.toString());
	}

	public void testMovingShapeTwoWithBigLimits() {
		animator.add(new RectangleShape(1, -5, 25, 35, new BouncingMotion(112, -15))); // added 25, 35, for task 2
		animator.clock(1000, 1000, painter);
		assertEquals("(rectangle 1,-5,25,35)", painter.toString());
	}

	public void testOvalShape() {
		animator.add(new OvalShape(1, -5, new BouncingMotion(112, -15)));
		animator.clock(painter);
		assertEquals("(oval 1,-5,25,35)", painter.toString());
	}
}
