import junit.framework.TestCase;

import java.awt.*;

public class TestBorderShape extends TestCase {
    private MockPainter painter;


    public void setUp() {
        painter = new MockPainter();
    }

    public void testShapeMoveWithBounceOffRight() {

        RectangleShape s = new RectangleShape(100, 20, 25, 35, new BouncingMotion(12, 15)); // added 25, 35, for task 2
        Shape shape = new BorderShape(s, 1, 1, Color.blue); // added 25, 35, for task 2
        shape.paint(painter);
        shape.move(0, 0, 135, 10000); // added 0, 0 for task 3
        shape.paint(painter);
        shape.move(0, 0, 135, 10000); // added 0, 0 for task 3
        shape.paint(painter);

        assertEquals("(color java.awt.Color[r=0,g=0,b=255](rectangle 98,18,28,38)" +
                "(color java.awt.Color[r=0,g=0,b=0](rectangle 100,20,25,35)" +
                "(color java.awt.Color[r=0,g=0,b=255](rectangle 106,33,28,38)" +
                "(color java.awt.Color[r=0,g=0,b=0](rectangle 108,35,25,35)" +
                "(color java.awt.Color[r=0,g=0,b=255](rectangle 94,48,28,38)" +
                "(color java.awt.Color[r=0,g=0,b=0](rectangle 96,50,25,35)", painter.toString());
    }

    // adapted from acoo079
    public void testBorderShapeBorderOnly() {
        int borderSize = 5;
        Shape inner = new RectangleShape(10, 10, 10, 10, new BouncingMotion(12, 15));
        BorderShape shape = new BorderShape(inner, borderSize, 0, null);
        assertEquals(shape.getWidth(), 10+borderSize*2);
        assertEquals(shape.getHeight(), 10+borderSize*2);
    }

    // adapted from acoo079
    public void testBorderShapeBorderAndGap() {
        int borderSize = 5;
        int gapSize = 2;
        Shape inner = new RectangleShape(10, 10, 10, 10, new BouncingMotion(12, 15));
        BorderShape shape = new BorderShape(inner, borderSize, gapSize, null);
        assertEquals(shape.getWidth(),  10+(borderSize+gapSize)*2);
        assertEquals(shape.getHeight(), 10+(borderSize+gapSize)*2);
    }

    // adapted from acoo079
    public void testTwoBorderShapesBounce() {

        int deltaX = 2;

        BouncingMotion motion = new BouncingMotion(deltaX, 0);

        int middleGap = 3;
        int middleBorder = 2;
        int outerGap = 5;
        int outerBorder = 4;

        Shape innerMost = new RectangleShape(50, 50, 10, 10, motion);
        Shape middle = new BorderShape(innerMost, middleBorder, middleGap, Color.BLACK);
        Shape outerMost = new BorderShape(middle, outerBorder, outerGap, Color.BLACK);

        int expectedWidth = 10 + 2*(middleGap+middleBorder+outerGap+outerBorder); // the total expected size of the shape
        int expectedX = innerMost.getX() - middleGap - middleBorder - outerGap - outerBorder;

        assertEquals(expectedWidth, outerMost.getWidth());
        assertEquals(expectedX, outerMost.x);

        outerMost.move(0, 0, expectedX+expectedWidth+1,expectedX+expectedWidth+1); // shape should hit the wall (have gone 1 over)
        outerMost.move(0, 0, expectedX+expectedWidth+1,expectedX+expectedWidth+1);

        assertEquals(innerMost.getX(), middle.getX()+middleGap+middleBorder);
        assertEquals(middle.getX(), outerMost.getX()+outerGap+outerBorder);
        assertEquals(outerMost.getX(), expectedX+1-deltaX ); // should now be one further behind it's starting position
    }

}
