import junit.framework.TestCase;

/**
 * some tests adapted from acoo079
 */
public class TestBounceListener extends TestCase {

    MockPainter painter;

    public void setUp() {
        painter = new MockPainter();
    }

    private boolean bounceOccurred;
    public void testEventOccurrsOnBounce() {
        bounceOccurred = false;

        BounceListener testListener = new BounceListener() {
            public void bounceOccurred() {
                bounceOccurred = true;
            }
        };

        Motion motion = new BouncingMotion(5, 0);
        motion.addBounceListener(testListener);

        Shape s = new RectangleShape(10, 10, 15, 15, motion);
        s.move(0, 0, 29, 10000); // During this method call a bounce should occur
        s.move(0, 0, 29, 10000);

        assertEquals(bounceOccurred, true);
    }


    public void testBounceEventWorksWithBounceMotion() {

        numOfBounces = 0;

        BounceListener testListener = new BounceListener() {
            public void bounceOccurred() {
                numOfBounces ++;
            }
        };

        Motion motion = new BouncingMotion(4, 5);
        motion.addBounceListener(testListener);
        Shape shape = new RectangleShape(10, 20, 15, 17, motion);

        int worldX = shape.getX()+shape.getWidth()+6; // 2 moves will rebound shape
        int worldY = shape.getY()+shape.getHeight()+4; // first move will rebound shape

        for (int i = 0; i < 3; i++) { // do 3 bounces
            shape.move(0, 0, worldX, worldY);
        }

        assertEquals(numOfBounces, 2); // asert that two events have fired

    }

    private int numOfBounces = 0;
}
